# aviary.hotpotqa

HotPotQA environment implemented with aviary,
allowing agents to perform multi-hop question answering on the HotPotQA dataset.

## References

[1] Yang et al. [HotpotQA: A Dataset for Diverse,
Explainable Multi-Hop Question Answering](https://aclanthology.org/D18-1259/). EMNLP, 2018.

[2] Yao et al.,
[ReAct: Synergizing Reasoning and Acting in Language Models](https://openreview.net/forum?id=WE_vluYUL-X).
In The Eleventh International Conference on Learning Representations. 2023

## Installation

To install the HotPotQA environment, run the following command:

```bash
pip install fhaviary[hotpotqa]
```
